-- $Id: Atlas_BurningCrusade.lua 20 2017-01-16 10:36:39Z arith $
--[[

	Atlas, a World of Warcraft instance map browser
	Copyright 2011 ~ 2017 - Arith Hsu, Atlas Team <atlas.addon at gmail dot com>

	This file is part of Atlas.

	Atlas is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	Atlas is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with Atlas; if not, write to the Free Software
	Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

--]]

local BZ = Atlas_GetLocaleLibBabble("LibBabble-SubZone-3.0");
local BF = Atlas_GetLocaleLibBabble("LibBabble-Faction-3.0");
local L = LibStub("AceLocale-3.0"):GetLocale("Atlas_BurningCrusade");
local ALC = LibStub("AceLocale-3.0"):GetLocale("Atlas");
local ALIL = Atlas_IngameLocales;

local BLUE = "|cff6666ff";
local GREN = "|cff66cc33";
local GREY = "|cff999999";
local LBLU = "|cff33cccc";
local _RED = "|cffcc3333";
local ORNG = "|cffcc9933";
local PINK = "|ccfcc33cc";
local PURP = "|cff9900ff";
local WHIT = "|cffffffff";
local YLOW = "|cffcccc33";
local INDENT = "      ";

local myMaps = {
--************************************************
-- Burning Crusade Instances
--************************************************

	AuchindounEnt = {
		ZoneName = { BZ["Auchindoun"]..ALC["L-Parenthesis"]..ALC["Entrance"]..ALC["R-Parenthesis"] };
		Location = { BZ["Terokkar Forest"] };
		LevelRange = "64-75";
		MinLevel = "62";
		PlayerLimit = "5";
		Acronym = L["Auch"];
		Module = "Atlas_BurningCrusade";
		{ BLUE.." A) "..BZ["Auchenai Crypts"], 10001 };
		{ BLUE.." B) "..BZ["Mana-Tombs"], 10002 };
		{ BLUE.." C) "..BZ["Sethekk Halls"], 10003 };
		{ BLUE.." D) "..BZ["Shadow Labyrinth"], 10004 };
		{ BLUE.." E) "..ALC["Entrance"], 10005 };
		{ GREN.." 1') "..L["Clarissa"], 10006 };
		{ GREN..INDENT..L["Greatfather Aldrimus"] };
		{ GREN..INDENT..L["Ha'lei"] };
		{ GREN..INDENT..L["Horvon the Armorer <Armorsmith>"] };
		{ GREN..INDENT..L["Ramdor the Mad"] };
		{ GREN.." 2') "..L["Nexus-Prince Haramad"], 10007 };
		{ GREN..INDENT..L["\"Slim\" <Shady Dealer>"] };
		{ GREN..INDENT..L["\"Captain\" Kaftiz"] };
		{ GREN.." 3') "..L["Dealer Tariq <Shady Dealer>"], 10008 };
		{ GREN..INDENT..L["Provisioner Tsaalt"] };
		{ GREN.." 4') "..ALC["Meeting Stone"], 10009 };
	};
	AuchAuchenaiCrypts = {
		ZoneName = { BZ["Auchindoun"]..ALC["Colon"]..BZ["Auchenai Crypts"] };
		Location = { BZ["Terokkar Forest"] };
		DungeonID = "149";
		DungeonHeroicID = "178";
		Acronym = L["AC"];
		WorldMapID = "722";
		JournalInstanceID = "247";
		Module = "Atlas_BurningCrusade";
		{ ORNG..REPUTATION..ALC["Colon"]..BF["Lower City"] };
		{ BLUE.." A) "..ALC["Entrance"], 10001 };
		{ GREN..INDENT..L["Draenei Spirit"] };
		{ WHIT.." 1) "..Atlas_GetBossName("Shirrak the Dead Watcher", 523), 523 };
		{ WHIT.." 2) "..Atlas_GetBossName("Exarch Maladaar", 524), 524 };
		{ WHIT..INDENT..L["Avatar of the Martyred"] };
		{ GREN..INDENT..L["D'ore"] };
		{ GREN.." 1') "..L["Tormented Soulpriest"], 10002 };
	};
	AuchManaTombs = {
		ZoneName = { BZ["Auchindoun"]..ALC["Colon"]..BZ["Mana-Tombs"] };
		Location = { BZ["Terokkar Forest"] };
		DungeonID = "148";
		DungeonHeroicID = "179";
		Acronym = L["MT"];
		WorldMapID = "732";
		JournalInstanceID = "250";
		Module = "Atlas_BurningCrusade";
		{ ORNG..REPUTATION..ALC["Colon"]..BF["The Consortium"] };
		{ ORNG..L["Key"]..ALC["Colon"]..ALIL["The Eye of Haramad"]..ALC["L-Parenthesis"]..ALC["Exalted"]..ALC["Comma"]..Atlas_GetBossName("Yor")..ALC["R-Parenthesis"] };
		{ BLUE.." A) "..ALC["Entrance"], 10001 };
		{ GREN..INDENT..L["Artificer Morphalius"] };
		{ GREN..INDENT..L["Mamdy the \"Ologist\""] };
		{ WHIT.." 1) "..Atlas_GetBossName("Pandemonius", 534), 534 };
		{ ORNG..INDENT..L["Shadow Lord Xiraxis"]..ALC["L-Parenthesis"]..ALC["Summon"]..ALC["R-Parenthesis"] };
		{ WHIT.." 2) "..Atlas_GetBossName("Tavarok", 535), 535 };
		{ WHIT.." 3) "..Atlas_GetBossName("Nexus-Prince Shaffar", 537), 537 };
		{ ORNG..INDENT..Atlas_GetBossName("Yor", 536)..ALC["L-Parenthesis"]..ALC["Summon"]..ALC["Comma"]..ALC["Heroic"]..ALC["R-Parenthesis"], 536 };
		{ GREN.." 1') "..L["Ambassador Pax'ivi"]..ALC["L-Parenthesis"]..ALC["Heroic"]..ALC["R-Parenthesis"], 10002 };
		{ GREN.." 2') "..L["Cryo-Engineer Sha'heen"], 10003 };
		{ GREN..INDENT..L["Ethereal Transporter Control Panel"] };
	};
	AuchSethekkHalls = {
		ZoneName = { BZ["Auchindoun"]..ALC["Colon"]..BZ["Sethekk Halls"] };
		Location = { BZ["Terokkar Forest"] };
		DungeonID = "150";
		DungeonHeroicID = "180";
		Acronym = L["Seth"];
		WorldMapID = "723";
		JournalInstanceID = "252";
		Module = "Atlas_BurningCrusade";
		{ ORNG..REPUTATION..ALC["Colon"]..BF["Lower City"] };
		{ BLUE.." A) "..ALC["Entrance"], 10001 };
		{ GREN..INDENT..L["Isfar"] };
		{ WHIT.." 1) "..Atlas_GetBossName("Darkweaver Syth", 541), 541 };
		{ GREN..INDENT..L["Dealer Vijaad"] };
		{ GREN..INDENT..L["Lakka"] };
		{ WHIT.." 2) "..Atlas_GetBossName("Anzu", 542)..ALC["L-Parenthesis"]..ALC["Heroic"]..ALC["R-Parenthesis"], 542 };
		{ GREN..INDENT..L["The Saga of Terokk"] };
		{ WHIT.." 3) "..Atlas_GetBossName("Talon King Ikiss", 543), 543 };
	};
	AuchShadowLabyrinth = {
		ZoneName = { BZ["Auchindoun"]..ALC["Colon"]..BZ["Shadow Labyrinth"] };
		Location = { BZ["Terokkar Forest"] };
		DungeonID = "151";
		DungeonHeroicID = "181";
		Acronym = L["SL"];
		WorldMapID = "724";
		JournalInstanceID = "253";
		Module = "Atlas_BurningCrusade";
		{ ORNG..REPUTATION..ALC["Colon"]..BF["Lower City"] };
		{ BLUE.." A) "..ALC["Entrance"], 10001 };
		{ GREN..INDENT..L["Field Commander Mahfuun"] };
		{ GREN..INDENT..L["Spy Grik'tha"] };
		{ WHIT.." 1) "..Atlas_GetBossName("Ambassador Hellmaw", 544), 544 };
		{ WHIT.." 2) "..Atlas_GetBossName("Blackheart the Inciter", 545), 545 };
		{ WHIT.." 3) "..Atlas_GetBossName("Grandmaster Vorpil", 546), 546 };
		{ GREN..INDENT..L["The Codex of Blood"] };
		{ WHIT.." 4) "..Atlas_GetBossName("Murmur", 547), 547 };
		{ ORNG.." 1) "..L["First Fragment Guardian"], 10002 };
		{ GREN..INDENT..ALC["Arcane Container"] };
		{ GREN.." 1') "..L["Spy To'gun"], 10003 };
	};
	BlackTempleStart = {
		ZoneName = { BZ["Black Temple"]..ALC["MapA"]..ALC["L-Parenthesis"]..ALC["Start"]..ALC["R-Parenthesis"] };
		Location = { BZ["Shadowmoon Valley"] };
		DungeonID = "196";
		Acronym = L["BT"];
		PlayerLimit = "25";
		WorldMapID = "796";
		DungeonLevel = "1";
		JournalInstanceID = "751";
		Module = "Atlas_BurningCrusade";
		NextMap = "BlackTempleBasement";
		{ ORNG..REPUTATION..ALC["Colon"]..BF["Ashtongue Deathsworn"] };
		{ BLUE.." A) "..ALC["Entrance"], 10001 };
		{ BLUE.." B) "..L["Towards Reliquary of Souls"], 10002 };
		{ BLUE.." C) "..L["Towards Teron Gorefiend"], 10003 };
		{ BLUE.." D) "..L["Towards Illidan Stormrage"], 10004 };
		{ WHIT.." 1) "..Atlas_GetBossName("High Warlord Naj'entus", 1582), 1582 };
		{ WHIT.." 2) "..Atlas_GetBossName("Supremus", 1583), 1583 };
		{ WHIT.." 3) "..Atlas_GetBossName("Shade of Akama", 1584), 1584 };
		{ GREN.." 1') "..L["Spirit of Olum"], 10008 };
		{ GREN.." 2') "..L["Spirit of Udalo"], 10009 };
		{ GREN..INDENT..L["Aluyen <Reagents>"] };
		{ GREN..INDENT..L["Okuno <Ashtongue Deathsworn Quartermaster>"] };
		{ GREN..INDENT..L["Seer Kanai"] };
	};
	BlackTempleBasement = {
		ZoneName = { BZ["Black Temple"]..ALC["MapB"]..ALC["L-Parenthesis"]..ALC["Basement"]..ALC["R-Parenthesis"] };
		Location = { BZ["Shadowmoon Valley"] };
		DungeonID = "196";
		Acronym = L["BT"];
		PlayerLimit = "25";
		WorldMapID = "796";
		DungeonLevel = "4";
		JournalInstanceID = "751";
		Module = "Atlas_BurningCrusade";
		PrevMap = "BlackTempleStart";
		NextMap = "BlackTempleTop";
		{ ORNG..REPUTATION..ALC["Colon"]..BF["Ashtongue Deathsworn"] };
		{ BLUE.." B) "..ALC["Entrance"], 10001 };
		{ BLUE.." C) "..ALC["Entrance"], 10002 };
		{ WHIT.." 4) "..Atlas_GetBossName("Gurtogg Bloodboil", 1586), 1586 };
		{ WHIT.." 5) "..Atlas_GetBossName("Reliquary of Souls", 1587), 1587 };
		{ WHIT..INDENT..Atlas_GetBossName("Essence of Suffering") };
		{ WHIT..INDENT..Atlas_GetBossName("Essence of Desire") };
		{ WHIT..INDENT..Atlas_GetBossName("Essence of Anger") };
		{ WHIT.." 6) "..Atlas_GetBossName("Teron Gorefiend", 1585), 1585 };
	};
	BlackTempleTop = {
		ZoneName = { BZ["Black Temple"]..ALC["MapC"]..ALC["L-Parenthesis"]..ALC["Top"]..ALC["R-Parenthesis"] };
		Location = { BZ["Shadowmoon Valley"] };
		DungeonID = "196";
		Acronym = L["BT"];
		PlayerLimit = "25";
		WorldMapID = "796";
		DungeonLevel = "8";
		JournalInstanceID = "751";
		Module = "Atlas_BurningCrusade";
		PrevMap = "BlackTempleBasement";
		{ ORNG..REPUTATION..ALC["Colon"]..BF["Ashtongue Deathsworn"] };
		{ BLUE.." D) "..ALC["Entrance"], 10001 };
		{ BLUE.." E) "..ALC["Connection"], 10002 };
		{ WHIT.." 7) "..Atlas_GetBossName("Mother Shahraz", 1588), 1588 };
		{ WHIT.." 8) "..Atlas_GetBossName("The Illidari Council", 1589), 1589 };
		{ WHIT..INDENT..Atlas_GetBossName("Lady Malande")..ALC["L-Parenthesis"]..Atlas_GetClassName("PRIEST")..ALC["R-Parenthesis"] };
		{ WHIT..INDENT..Atlas_GetBossName("Gathios the Shatterer")..ALC["L-Parenthesis"]..Atlas_GetClassName("PALADIN")..ALC["R-Parenthesis"] };
		{ WHIT..INDENT..Atlas_GetBossName("High Nethermancer Zerevor")..ALC["L-Parenthesis"]..Atlas_GetClassName("MAGE")..ALC["R-Parenthesis"] };
		{ WHIT..INDENT..Atlas_GetBossName("Veras Darkshadow")..ALC["L-Parenthesis"]..Atlas_GetClassName("ROGUE")..ALC["R-Parenthesis"] };
		{ WHIT.." 9) "..Atlas_GetBossName("Illidan Stormrage", 1590), 1590 };
	};
	CoilfangReservoirEnt = {
		ZoneName = { BZ["Coilfang Reservoir"]..ALC["L-Parenthesis"]..ALC["Entrance"]..ALC["R-Parenthesis"] };
		Location = { BZ["Zangarmarsh"] };
		LevelRange = "62-73";
		MinLevel = "61";
		PlayerLimit = "5/25";
		Acronym = L["CR"];
		Module = "Atlas_BurningCrusade";
		{ BLUE.." A) "..BZ["The Slave Pens"], 10001 };
		{ BLUE.." B) "..BZ["The Steamvault"], 10002 };
		{ BLUE.." C) "..BZ["Serpentshrine Cavern"], 10003 };
		{ BLUE.." D) "..BZ["The Underbog"], 10004 };
		{ BLUE.." E) "..ALC["Entrance"]..ALC["L-Parenthesis"]..ALC["Underwater"]..ALC["R-Parenthesis"], 10005 };
		{ GREN.." 1') "..ALC["Meeting Stone"], 10006 };
		{ GREN.." 2') "..L["Mortog Steamhead"], 10007 };
	};
	CFRSerpentshrineCavern = {
		ZoneName = { BZ["Coilfang Reservoir"]..ALC["Colon"]..BZ["Serpentshrine Cavern"] };
		Location = { BZ["Zangarmarsh"] };
		DungeonID = "194";
		Acronym = L["SSC"];
		PlayerLimit = "25";
		WorldMapID = "780";
		JournalInstanceID = "748";
		Module = "Atlas_BurningCrusade";
		{ ORNG..REPUTATION..ALC["Colon"]..BF["Cenarion Expedition"] };
		{ BLUE.." A) "..ALC["Entrance"], 10001 };
		{ BLUE.." B) "..ALC["Elevator"], 10002 };
		{ WHIT.." 1) "..Atlas_GetBossName("Hydross the Unstable", 1567), 1567 };
		{ WHIT.." 2) "..Atlas_GetBossName("The Lurker Below", 1568), 1568 };
		{ WHIT.." 3) "..Atlas_GetBossName("Leotheras the Blind", 1569), 1569 };
		{ WHIT.." 4) "..Atlas_GetBossName("Fathom-Lord Karathress", 1570), 1570 };
		{ GREN..INDENT..L["Seer Olum"] };
		{ WHIT.." 5) "..Atlas_GetBossName("Morogrim Tidewalker", 1571), 1571 };
		{ WHIT.." 6) "..Atlas_GetBossName("Lady Vashj", 1572), 1572 };
	};
	CFRTheSlavePens = {
		ZoneName = { BZ["Coilfang Reservoir"]..ALC["Colon"]..BZ["The Slave Pens"] };
		Location = { BZ["Zangarmarsh"] };
		DungeonID = "140";
		DungeonHeroicID = "184";
		Acronym = L["SP"];
		WorldMapID = "728";
		JournalInstanceID = "260";
		Module = "Atlas_BurningCrusade";
		{ ORNG..REPUTATION..ALC["Colon"]..BF["Cenarion Expedition"] };
		{ BLUE.." A) "..ALC["Entrance"], 10001 };
		{ GREN..INDENT..L["Nahuud"] };
		{ GREN..INDENT..L["Watcher Jhang"] };
		{ WHIT.." 1) "..Atlas_GetBossName("Mennu the Betrayer", 570), 570 };
		{ WHIT.." 2) "..Atlas_GetBossName("Rokmar the Crackler", 571), 571 };
		{ WHIT.." 3) "..Atlas_GetBossName("Quagmirran", 572), 572 };
		{ ORNG.." 1) "..Atlas_GetBossName("Ahune")..ALC["L-Parenthesis"]..ALC["Midsummer Festival"]..ALC["R-Parenthesis"], 10002 };
		{ GREN.." 1') "..L["Weeder Greenthumb"], 10003 };
		{ GREN.." 2') "..L["Skar'this the Heretic"]..ALC["L-Parenthesis"]..ALC["Heroic"]..ALC["R-Parenthesis"], 10004 };
		{ GREN.." 3') "..L["Naturalist Bite"], 10005 };
	};
	CFRTheSteamvault = {
		ZoneName = { BZ["Coilfang Reservoir"]..ALC["Colon"]..BZ["The Steamvault"] };
		Location = { BZ["Zangarmarsh"] };
		DungeonID = "147";
		DungeonHeroicID = "185";
		Acronym = L["SV"];
		WorldMapID = "727";
		JournalInstanceID = "261";
		Module = "Atlas_BurningCrusade";
		{ ORNG..REPUTATION..ALC["Colon"]..BF["Cenarion Expedition"] };
		{ BLUE.." A) "..ALC["Entrance"], 10001 };
		{ GREN..INDENT..L["Naturalist Bite"] };
		{ GREN..INDENT..L["Watcher Jhang"] };
		{ GREN..INDENT..L["Windcaller Claw"] };
		{ WHIT.." 1) "..Atlas_GetBossName("Hydromancer Thespia", 573), 573 };
		{ GREN..INDENT..L["Main Chambers Access Panel"] };
		{ WHIT.." 2) "..Atlas_GetBossName("Mekgineer Steamrigger", 574), 574 };
		{ GREN..INDENT..L["Main Chambers Access Panel"] };
		{ WHIT.." 3) "..Atlas_GetBossName("Warlord Kalithresh", 575), 575 };
		{ ORNG.." 1) "..L["Second Fragment Guardian"], 10002 };
		{ GREN..INDENT..ALC["Arcane Container"] };
	};
	CFRTheUnderbog = {
		ZoneName = { BZ["Coilfang Reservoir"]..ALC["Colon"]..BZ["The Underbog"] };
		Location = { BZ["Zangarmarsh"] };
		DungeonID = "146";
		DungeonHeroicID = "186";
		Acronym = L["UB"];
		WorldMapID = "726";
		JournalInstanceID = "262";
		Module = "Atlas_BurningCrusade";
		{ ORNG..REPUTATION..ALC["Colon"]..BF["Cenarion Expedition"] };
		{ BLUE.." A) "..ALC["Entrance"], 10001 };
		{ GREN..INDENT..L["Naturalist Bite"] };
		{ GREN..INDENT..L["T'shu"] };
		{ GREN..INDENT..L["Watcher Jhang"] };
		{ WHIT.." 1) "..Atlas_GetBossName("Hungarfen", 576), 576 };
		{ GREN..INDENT..L["The Underspore"] };
		{ WHIT.." 2) "..Atlas_GetBossName("Ghaz'an", 577), 577 };
		{ WHIT.." 3) "..Atlas_GetBossName("Swamplord Musel'ek", 578), 578 };
		{ WHIT..INDENT..Atlas_GetBossName("Claw") };
		{ WHIT.." 4) "..Atlas_GetBossName("The Black Stalker", 579), 579 };
		{ GREN.." 1') "..L["Earthbinder Rayge"], 10002 };
	};
	CoTBlackMorass = {
		ZoneName = { BZ["Caverns of Time"]..ALC["Colon"]..BZ["The Black Morass"] };
		Location = { BZ["Tanaris"] };
		LevelRange = "68-75";
		MinLevel = "68";
		PlayerLimit = "5";
		Acronym = L["CoT2"];
		WorldMapID = "733";
		JournalInstanceID = "255";
		Module = "Atlas_BurningCrusade";
		{ PURP..ALC["Event"]..ALC["Colon"]..BZ["Opening of the Dark Portal"] };
		{ ORNG..ALC["Attunement Required"] };
		{ ORNG..REPUTATION..ALC["Colon"]..BF["Keepers of Time"] };
		{ BLUE.." A) "..ALC["Entrance"], 10001 };
		{ GREN..INDENT..L["Sa'at <Keepers of Time>"] };
		{ ORNG.." X) "..ALC["Portal"]..ALC["L-Parenthesis"]..ALC["Spawn Point"]..ALC["R-Parenthesis"], 10002 };
		{ WHIT..INDENT..ALC["Wave 6"]..ALC["Colon"]..Atlas_GetBossName("Chrono Lord Deja", 552), 552 };
		{ WHIT..INDENT..ALC["Wave 12"]..ALC["Colon"]..Atlas_GetBossName("Temporus", 553), 553 };
		{ WHIT..INDENT..ALC["Wave 18"]..ALC["Colon"]..Atlas_GetBossName("Aeonus", 554), 554 };
		{ GREN.." 1') "..BZ["The Dark Portal"], 10003 };
		{ GREN..INDENT..Atlas_GetBossName("Medivh") };
	};
	CoTHyjalEnt = {
		ZoneName = { BZ["Caverns of Time"]..ALC["Colon"]..BZ["Hyjal Summit"]..ALC["L-Parenthesis"]..ALC["Entrance"]..ALC["R-Parenthesis"] };
		Location = { BZ["Tanaris"] };
		LevelRange = "70-73";
		MinLevel = "70";
		PlayerLimit = "25";
		Acronym = L["CoT3"];
		Module = "Atlas_BurningCrusade";
		{ PURP..ALC["Event"]..ALC["Colon"]..BZ["The Battle for Mount Hyjal"] };
		{ ORNG..REPUTATION..ALC["Colon"]..BF["The Scale of the Sands"] };
		{ BLUE.." A) "..ALC["Entrance"], 10001 };
		{ BLUE.." B) "..BZ["Alliance Base"], 10002 };
		{ BLUE.." C) "..BZ["Horde Encampment"], 10003 };
		{ BLUE.." D) "..BZ["Night Elf Village"], 10004 };
		{ GREN.." 1') "..L["Indormi <Keeper of Ancient Gem Lore>"], 10005 };
		{ GREN..INDENT..L["Tydormu <Keeper of Lost Artifacts>"] };
	};
	CoTHyjal = {
		ZoneName = { BZ["Caverns of Time"]..ALC["Colon"]..BZ["Hyjal Summit"] };
		Location = { BZ["Tanaris"] };
		LevelRange = "70-73";
		MinLevel = "70";
		PlayerLimit = "25";
		Acronym = L["CoT3"];
		WorldMapID = "775";
		JournalInstanceID = "750";
		Module = "Atlas_BurningCrusade";
		{ PURP..ALC["Event"]..ALC["Colon"]..BZ["The Battle for Mount Hyjal"] };
		{ ORNG..REPUTATION..ALC["Colon"]..BF["The Scale of the Sands"] };
		{ BLUE.." A) "..BZ["Alliance Base"], 10001 };
		{ GREN..INDENT..L["Lady Jaina Proudmoore"] };
		{ BLUE.." B) "..BZ["Horde Encampment"], 10002 };
		{ GREN..INDENT..L["Thrall <Warchief>"] };
		{ BLUE.." C) "..BZ["Night Elf Village"], 10003 };
		{ GREN..INDENT..L["Tyrande Whisperwind <High Priestess of Elune>"] };
		{ WHIT.." 1) "..Atlas_GetBossName("Rage Winterchill", 1577), 1577 };
		{ WHIT.." 2) "..Atlas_GetBossName("Anetheron", 1578), 1578 };
		{ WHIT.." 3) "..Atlas_GetBossName("Kaz'rogal", 1579), 1579 };
		{ WHIT.." 4) "..Atlas_GetBossName("Azgalor", 1580), 1580 };
		{ WHIT.." 5) "..Atlas_GetBossName("Archimonde", 1581), 1581 };
	};
	CoTOldHillsbrad = {
		ZoneName = { BZ["Caverns of Time"]..ALC["Colon"]..BZ["Old Hillsbrad Foothills"] };
		Location = { BZ["Tanaris"] };
		LevelRange = "66-68 / 70";
		MinLevel = "66";
		PlayerLimit = "5";
		Acronym = L["CoT1"];
		WorldMapID = "734";
		JournalInstanceID = "251";
		Module = "Atlas_BurningCrusade";
		{ PURP..ALC["Event"]..ALC["Colon"]..BZ["The Escape From Durnholde"] };
		{ ORNG..ALC["Attunement Required"] };
		{ ORNG..REPUTATION..ALC["Colon"]..BF["Keepers of Time"] };
		{ BLUE.." A) "..ALC["Entrance"], 10001 };
		{ GREN..INDENT..L["Erozion"] };
		{ GREN..INDENT..L["Brazen"] };
		{ BLUE.." B) "..L["Landing Spot"], 10002 };
		{ BLUE.." C) "..BZ["Southshore"], 10003 };
		{ BLUE.." D) "..BZ["Tarren Mill"], 10004 };
		{ WHIT.." 1) "..Atlas_GetBossName("Lieutenant Drake", 538), 538 };
		{ GREN.." 1') "..L["Thrall"]..ALC["L-Parenthesis"]..ALC["Lower"]..ALC["R-Parenthesis"], 10005 };
		{ WHIT.." 2) "..Atlas_GetBossName("Captain Skarloc", 539), 539 };
		{ GREN..INDENT..L["Thrall"]..ALC["L-Parenthesis"]..ALC["Second Stop"]..ALC["R-Parenthesis"] };
		{ GREN.." 2') "..L["Thrall"]..ALC["L-Parenthesis"]..ALC["Third Stop"]..ALC["R-Parenthesis"], 10006 };
		{ WHIT.." 3) "..Atlas_GetBossName("Epoch Hunter", 540), 540 };
		{ GREN..INDENT..L["Thrall"]..ALC["L-Parenthesis"]..ALC["Fourth Stop"]..ALC["Comma"]..ALC["Upper"]..ALC["R-Parenthesis"] };
		{ GREN..INDENT..L["Taretha"]..ALC["L-Parenthesis"]..ALC["Upper"]..ALC["R-Parenthesis"] };
		{ WHIT.." 4) "..L["Don Carlos"]..ALC["L-Parenthesis"]..ALC["Wanders"]..ALC["R-Parenthesis"], 10007 };
		{ WHIT..INDENT..INDENT..L["Guerrero"]..ALC["L-Parenthesis"]..ALC["Wanders"]..ALC["R-Parenthesis"] };
		{ GREN..INDENT..L["Thomas Yance <Travelling Salesman>"]..ALC["L-Parenthesis"]..ALC["Wanders"]..ALC["R-Parenthesis"] };
		{ GREN..INDENT..L["Aged Dalaran Wizard"]..ALC["L-Parenthesis"]..ALC["Wanders"]..ALC["R-Parenthesis"] };
		{ GREN.." 3') "..L["Jonathan Revah"], 10008 };
		{ GREN..INDENT..L["Jerry Carter"] };
		{ "" };
		{ "" };
		{ "" };
		{ ORNG..BZ["Southshore"] };
		{ GREN..INDENT..Atlas_GetBossName("Kel'Thuzad") };
		{ GREN..INDENT..L["Helcular"] };
		{ GREN..INDENT..L["Farmer Kent"] };
		{ GREN..INDENT..L["Sally Whitemane"] };
		{ GREN..INDENT..L["Renault Mograine"] };
		{ GREN..INDENT..L["Little Jimmy Vishas"] };
		{ GREN..INDENT..L["Herod the Bully"] };
		{ GREN..INDENT..L["Nat Pagle"] };
		{ GREN..INDENT..L["Hal McAllister"] };
		{ GREN..INDENT..L["Zixil <Aspiring Merchant>"] };
		{ GREN..INDENT..L["Overwatch Mark 0 <Protector>"] };
		{ "" };
		{ ORNG..L["Southshore Inn"] };
		{ GREN..INDENT..L["Captain Edward Hanes"] };
		{ GREN..INDENT..L["Captain Sanders"] };
		{ GREN..INDENT..L["Commander Mograine"] };
		{ GREN..INDENT..L["Isillien"] };
		{ GREN..INDENT..L["Abbendis"] };
		{ GREN..INDENT..L["Fairbanks"] };
		{ GREN..INDENT..Atlas_GetBossName("Tirion Fordring") };
		{ GREN..INDENT..Atlas_GetBossName("Arcanist Doan") };
		{ GREN..INDENT..L["Taelan"]..ALC["L-Parenthesis"]..ALC["Upper"]..ALC["R-Parenthesis"] };
		{ GREN..INDENT..L["Barkeep Kelly <Bartender>"] };
		{ GREN..INDENT..L["Frances Lin <Barmaid>"] };
		{ GREN..INDENT..L["Chef Jessen <Speciality Meat & Slop>"] };
		{ GREN..INDENT..L["Stalvan Mistmantle"]..ALC["L-Parenthesis"]..ALC["Upper"]..ALC["R-Parenthesis"] };
		{ GREN..INDENT..L["Phin Odelic <The Kirin Tor>"]..ALC["L-Parenthesis"]..ALC["Upper"]..ALC["R-Parenthesis"] };
		{ "" };
		{ ORNG..BZ["Southshore Town Hall"] };
		{ GREN..INDENT..L["Magistrate Henry Maleb"] };
		{ GREN..INDENT..L["Raleigh the True"] };
		{ GREN..INDENT..L["Nathanos Marris"] };
		{ GREN..INDENT..L["Bilger the Straight-laced"] };
		{ "" };
		{ ORNG..BZ["Tarren Mill"] };
		{ GREN..INDENT..L["Innkeeper Monica"] };
		{ GREN..INDENT..L["Julie Honeywell"] };
		{ GREN..INDENT..L["Jay Lemieux"] };
		{ GREN..INDENT..L["Young Blanchy"] };
	};
	GruulsLair = {
		ZoneName = { BZ["Gruul's Lair"] };
		Location = { BZ["Blade's Edge Mountains"] };
		DungeonID = "177";
		Acronym = L["GL"];
		PlayerLimit = "25";
		WorldMapID = "776";
		JournalInstanceID = "746";
		Module = "Atlas_BurningCrusade";
		{ BLUE.." A) "..ALC["Entrance"], 10001 };
		{ WHIT.." 1) "..Atlas_GetBossName("High King Maulgar", 1564), 1564 };
		{ WHIT..INDENT..Atlas_GetBossName("Kiggler the Crazed")..ALC["L-Parenthesis"]..Atlas_GetClassName("SHAMAN")..ALC["R-Parenthesis"] };
		{ WHIT..INDENT..Atlas_GetBossName("Blindeye the Seer")..ALC["L-Parenthesis"]..Atlas_GetClassName("PRIEST")..ALC["R-Parenthesis"] };
		{ WHIT..INDENT..Atlas_GetBossName("Olm the Summoner")..ALC["L-Parenthesis"]..Atlas_GetClassName("WARLOCK")..ALC["R-Parenthesis"] };
		{ WHIT..INDENT..Atlas_GetBossName("Krosh Firehand")..ALC["L-Parenthesis"]..Atlas_GetClassName("MAGE")..ALC["R-Parenthesis"] };
		{ WHIT.." 2) "..Atlas_GetBossName("Gruul the Dragonkiller", 1565), 1565 };
	};
	HellfireCitadelEnt = {
		ZoneName = { BZ["Hellfire Citadel"]..ALC["L-Parenthesis"]..ALC["Entrance"]..ALC["R-Parenthesis"] };
		Location = { BZ["Hellfire Peninsula"] };
		LevelRange = "59-73";
		MinLevel = "57";
		PlayerLimit = "5/25";
		Acronym = L["HC"];
		Module = "Atlas_BurningCrusade";
		{ BLUE.." A) "..BZ["Hellfire Ramparts"], 10001 };
		{ BLUE.." B) "..BZ["The Shattered Halls"], 10002 };
		{ BLUE.." C) "..BZ["The Blood Furnace"], 10003 };
		{ BLUE.." D) "..BZ["Magtheridon's Lair"], 10004 };
		{ GREN.." 1') "..L["Meeting Stone of Magtheridon's Lair"], 10005 };
		{ GREN.." 2') "..L["Meeting Stone of Hellfire Citadel"], 10006 };
		{ GREN.." 3') "..L["Steps and path to the Blood Furnace"], 10007 };
		{ GREN.." 4') "..L["Path to the Hellfire Ramparts and Shattered Halls"], 10008 };
	};
	HCBloodFurnace = {
		ZoneName = { BZ["Hellfire Citadel"]..ALC["Colon"]..BZ["The Blood Furnace"] };
		Location = { BZ["Hellfire Peninsula"] };
		DungeonID = "137";
		DungeonHeroicID = "187";
		Acronym = L["BF"];
		WorldMapID = "725";
		JournalInstanceID = "256";
		Module = "Atlas_BurningCrusade";
		{ ORNG..REPUTATION..ALC["Colon"]..BF["Honor Hold"]..ALC["L-Parenthesis"]..FACTION_ALLIANCE..ALC["R-Parenthesis"] };
		{ ORNG..REPUTATION..ALC["Colon"]..BF["Thrallmar"]..ALC["L-Parenthesis"]..FACTION_HORDE..ALC["R-Parenthesis"] };
		{ BLUE.." A) "..ALC["Entrance"], 10001 };
		{ GREN..INDENT..L["Gunny"]..ALC["L-Parenthesis"]..FACTION_ALLIANCE..ALC["R-Parenthesis"] };
		{ GREN..INDENT..L["Caza'rez"]..ALC["L-Parenthesis"]..FACTION_HORDE..ALC["R-Parenthesis"] };
		{ WHIT.." 1) "..Atlas_GetBossName("The Maker", 555), 555 };
		{ WHIT.." 2) "..Atlas_GetBossName("Broggok", 556), 556 };
		{ WHIT.." 3) "..Atlas_GetBossName("Keli'dan the Breaker", 557), 557 };
	};
	HCHellfireRamparts = {
		ZoneName = { BZ["Hellfire Citadel"]..ALC["Colon"]..BZ["Hellfire Ramparts"] };
		Location = { BZ["Hellfire Peninsula"] };
		DungeonID = "136";
		DungeonHeroicID = "188";
		Acronym = L["Ramp"];
		WorldMapID = "797";
		JournalInstanceID = "248";
		Module = "Atlas_BurningCrusade";
		{ ORNG..REPUTATION..ALC["Colon"]..BF["Honor Hold"]..ALC["L-Parenthesis"]..FACTION_ALLIANCE..ALC["R-Parenthesis"] };
		{ ORNG..REPUTATION..ALC["Colon"]..BF["Thrallmar"]..ALC["L-Parenthesis"]..FACTION_HORDE..ALC["R-Parenthesis"] };
		{ BLUE.." A) "..ALC["Entrance"], 10001 };
		{ GREN..INDENT..L["Advance Scout Chadwick"]..ALC["L-Parenthesis"]..FACTION_ALLIANCE..ALC["R-Parenthesis"] };
		{ GREN..INDENT..L["Stone Guard Stok'ton"]..ALC["L-Parenthesis"]..FACTION_HORDE..ALC["R-Parenthesis"] };
		{ WHIT.." 1) "..Atlas_GetBossName("Watchkeeper Gargolmar", 527), 527 };
		{ WHIT.." 2) "..Atlas_GetBossName("Omor the Unscarred", 528), 528 };
		{ WHIT.." 3) "..Atlas_GetBossName("Vazruden the Herald", 529), 529 };
		{ WHIT..INDENT..Atlas_GetBossName("Nazan") };
		{ GREN..INDENT..L["Reinforced Fel Iron Chest"] };
	};
	HCMagtheridonsLair = {
		ZoneName = { BZ["Hellfire Citadel"]..ALC["Colon"]..BZ["Magtheridon's Lair"] };
		Location = { BZ["Hellfire Peninsula"] };
		DungeonID = "176";
		Acronym = L["Mag"];
		PlayerLimit = "25";
		WorldMapID = "779";
		JournalInstanceID = "747";
		Module = "Atlas_BurningCrusade";
		{ BLUE.." A) "..ALC["Entrance"], 10001 };
		{ WHIT.." 1) "..Atlas_GetBossName("Magtheridon", 1566), 1566 };
	};
	HCTheShatteredHalls = {
		ZoneName = { BZ["Hellfire Citadel"]..ALC["Colon"]..BZ["The Shattered Halls"] };
		Location = { BZ["Hellfire Peninsula"] };
		DungeonID = "138";
		DungeonHeroicID = "189";
		Acronym = L["SH"];
		WorldMapID = "710";
		JournalInstanceID = "259";
		Module = "Atlas_BurningCrusade";
		{ ORNG..REPUTATION..ALC["Colon"]..BF["Honor Hold"]..ALC["L-Parenthesis"]..FACTION_ALLIANCE..ALC["R-Parenthesis"] };
		{ ORNG..REPUTATION..ALC["Colon"]..BF["Thrallmar"]..ALC["L-Parenthesis"]..FACTION_HORDE..ALC["R-Parenthesis"] };
		{ BLUE.." A) "..ALC["Entrance"], 10001 };
		{ GREN..INDENT..L["Advance Scout Chadwick"]..ALC["L-Parenthesis"]..FACTION_ALLIANCE..ALC["R-Parenthesis"] };
		{ GREN..INDENT..L["Gunny"]..ALC["L-Parenthesis"]..FACTION_ALLIANCE..ALC["R-Parenthesis"] };
		{ GREN..INDENT..L["Caza'rez"]..ALC["L-Parenthesis"]..FACTION_HORDE..ALC["R-Parenthesis"] };
		{ GREN..INDENT..L["Stone Guard Stok'ton"]..ALC["L-Parenthesis"]..FACTION_HORDE..ALC["R-Parenthesis"] };
		{ WHIT.." 1) "..Atlas_GetBossName("Grand Warlock Nethekurse", 566), 566 };
		{ WHIT.." 2) "..Atlas_GetBossName("Blood Guard Porung", 728)..ALC["L-Parenthesis"]..ALC["Heroic"]..ALC["R-Parenthesis"], 728 };
		{ WHIT.." 3) "..Atlas_GetBossName("Warbringer O'mrogg", 568), 568 };
		{ WHIT.." 4) "..Atlas_GetBossName("Warchief Kargath Bladefist", 569), 569 };
		{ WHIT..INDENT..L["Shattered Hand Executioner"]..ALC["L-Parenthesis"]..ALC["Heroic"]..ALC["R-Parenthesis"] };
		{ GREN..INDENT..L["Private Jacint"]..ALC["L-Parenthesis"]..FACTION_ALLIANCE..ALC["Comma"]..ALC["Heroic"]..ALC["R-Parenthesis"] };
		{ GREN..INDENT..L["Rifleman Brownbeard"]..ALC["L-Parenthesis"]..FACTION_ALLIANCE..ALC["Comma"]..ALC["Heroic"]..ALC["R-Parenthesis"] };
		{ GREN..INDENT..L["Captain Alina"]..ALC["L-Parenthesis"]..FACTION_ALLIANCE..ALC["Comma"]..ALC["Heroic"]..ALC["R-Parenthesis"] };
		{ GREN..INDENT..L["Scout Orgarr"]..ALC["L-Parenthesis"]..FACTION_HORDE..ALC["Comma"]..ALC["Heroic"]..ALC["R-Parenthesis"] };
		{ GREN..INDENT..L["Korag Proudmane"]..ALC["L-Parenthesis"]..FACTION_HORDE..ALC["Comma"]..ALC["Heroic"]..ALC["R-Parenthesis"] };
		{ GREN..INDENT..L["Captain Boneshatter"]..ALC["L-Parenthesis"]..FACTION_HORDE..ALC["Comma"]..ALC["Heroic"]..ALC["R-Parenthesis"] };
		{ GREN.." 1') "..L["Randy Whizzlesprocket"]..ALC["L-Parenthesis"]..FACTION_ALLIANCE..ALC["Comma"]..ALC["Heroic"]..ALC["R-Parenthesis"], 10002 };
		{ GREN..INDENT..L["Drisella"]..ALC["L-Parenthesis"]..FACTION_HORDE..ALC["Comma"]..ALC["Heroic"]..ALC["R-Parenthesis"] };
	};
	KarazhanEnt = {
		ZoneName = { BZ["Karazhan"]..ALC["L-Parenthesis"]..ALC["Entrance"]..ALC["R-Parenthesis"] };
		Location = { BZ["Deadwind Pass"] };
		DungeonID = "175";
		PlayerLimit = "10";
		Acronym = L["Kara"];
		WorldMapID = "799";
		JournalInstanceID = "745";
		Module = "Atlas_BurningCrusade";
		NextMap = "KarazhanStart";
		{ BLUE.." A) "..BZ["Karazhan"]..ALC["L-Parenthesis"]..ALC["Front"]..ALC["R-Parenthesis"], 10001 };
		{ BLUE.." B) "..BZ["Karazhan"]..ALC["L-Parenthesis"]..ALC["Back"]..ALC["R-Parenthesis"], 10002 };
		{ GREN.." 1') "..L["Archmage Leryda"], 10003 };
		{ GREN..INDENT..L["Archmage Alturus"] };
		{ GREN..INDENT..L["Apprentice Darius"] };
		{ GREN.." 2') "..L["Stairs to Underground Pond"], 10004 };
		{ GREN.." 3') "..L["Stairs to Underground Well"], 10005 };
		{ GREN.." 4') "..L["Charred Bone Fragment"], 10006 };
		{ GREN.." 5') "..ALC["Meeting Stone"], 10007 };
		{ GREN.." 6') "..ALC["Graveyard"], 10008 };
	};
	KarazhanStart = {
		ZoneName = { BZ["Karazhan"]..ALC["MapA"]..ALC["L-Parenthesis"]..ALC["Start"]..ALC["R-Parenthesis"] };
		Location = { BZ["Deadwind Pass"] };
		DungeonID = "175";
		Acronym = L["Kara"];
		PlayerLimit = "10";
		WorldMapID = "799";
		JournalInstanceID = "745";
		Module = "Atlas_BurningCrusade";
		PrevMap = "KarazhanEnt";
		NextMap = "KarazhanEnd";
		{ ORNG..REPUTATION..ALC["Colon"]..BF["The Violet Eye"] };
		{ BLUE.." A) "..ALC["Entrance"]..ALC["L-Parenthesis"]..ALC["Front"]..ALC["R-Parenthesis"], 10001 };
		{ BLUE.." B-J) "..ALC["Connection"], 10002 };
		{ WHIT.." 1) "..Atlas_GetBossName("Attumen the Huntsman", 1553), 1553 };
		{ WHIT..INDENT..Atlas_GetBossName("Midnight") };
		{ WHIT.." 2) "..Atlas_GetBossName("Moroes", 1554), 1554 };
		{ WHIT..INDENT..L["Baroness Dorothea Millstipe"]..ALC["L-Parenthesis"]..ALC["Random"]..ALC["Comma"]..ALC["Shadow Priest"]..ALC["R-Parenthesis"] };
		{ WHIT..INDENT..L["Lady Catriona Von'Indi"]..ALC["L-Parenthesis"]..ALC["Random"]..ALC["Comma"]..ALC["Holy Priest"]..ALC["R-Parenthesis"] };
		{ WHIT..INDENT..L["Lady Keira Berrybuck"]..ALC["L-Parenthesis"]..ALC["Random"]..ALC["Comma"]..ALC["Holy Paladin"]..ALC["R-Parenthesis"] };
		{ WHIT..INDENT..L["Baron Rafe Dreuger"]..ALC["L-Parenthesis"]..ALC["Random"]..ALC["Comma"]..ALC["Retribution Paladin"]..ALC["R-Parenthesis"] };
		{ WHIT..INDENT..L["Lord Robin Daris"]..ALC["L-Parenthesis"]..ALC["Random"]..ALC["Comma"]..ALC["Arms Warrior"]..ALC["R-Parenthesis"] };
		{ WHIT..INDENT..L["Lord Crispin Ference"]..ALC["L-Parenthesis"]..ALC["Random"]..ALC["Comma"]..ALC["Protection Warrior"]..ALC["R-Parenthesis"] };
		{ WHIT.." 3) "..Atlas_GetBossName("Maiden of Virtue", 1555), 1555 };
		--{ WHIT.." 4) "..Atlas_GetBossName("Opera Event"), 10006 };
		{ WHIT.." 4) "..Atlas_GetBossName("Opera Hall", 1556), 1556 };
		{ ORNG..INDENT..L["Red Riding Hood"]..ALC["L-Parenthesis"]..ALC["Random"]..ALC["R-Parenthesis"] };
		{ WHIT..INDENT..INDENT..Atlas_GetBossName("The Big Bad Wolf") };
		{ ORNG..INDENT..L["Wizard of Oz"]..ALC["L-Parenthesis"]..ALC["Random"]..ALC["R-Parenthesis"] };
		{ WHIT..INDENT..INDENT..Atlas_GetBossName("Dorothee") };
		{ WHIT..INDENT..INDENT..Atlas_GetBossName("Tito") };
		{ WHIT..INDENT..INDENT..Atlas_GetBossName("Strawman") };
		{ WHIT..INDENT..INDENT..Atlas_GetBossName("Tinhead") };
		{ WHIT..INDENT..INDENT..Atlas_GetBossName("Roar") };
		{ WHIT..INDENT..INDENT..Atlas_GetBossName("The Crone", 1557), 1557 };
		{ ORNG..INDENT..Atlas_GetBossName("Romulo & Julianne")..ALC["L-Parenthesis"]..ALC["Random"]..ALC["R-Parenthesis"] };
		{ WHIT..INDENT..INDENT..Atlas_GetBossName("Romulo") };
		{ WHIT..INDENT..INDENT..Atlas_GetBossName("Julianne") };
		{ WHIT.." 5 ) "..Atlas_GetBossName("Nightbane")..ALC["L-Parenthesis"]..ALC["Summon"]..ALC["R-Parenthesis"], 10018 };
		{ GREN..INDENT..L["The Master's Terrace"] };
		{ ORNG.." 1) "..Atlas_GetBossName("Servant Quarters", 1552), 1552 };
		{ ORNG..INDENT..Atlas_GetBossName("Hyakiss the Lurker")..ALC["L-Parenthesis"]..ALC["Rare"]..ALC["Comma"]..ALC["Random"]..ALC["R-Parenthesis"] };
		{ ORNG..INDENT..Atlas_GetBossName("Rokad the Ravager")..ALC["L-Parenthesis"]..ALC["Rare"]..ALC["Comma"]..ALC["Random"]..ALC["R-Parenthesis"] };
		{ ORNG..INDENT..Atlas_GetBossName("Shadikith the Glider")..ALC["L-Parenthesis"]..ALC["Rare"]..ALC["Comma"]..ALC["Random"]..ALC["R-Parenthesis"] };
		{ GREN.." 1') "..L["Hastings <The Caretaker>"], 10009 };
		{ GREN.." 2') "..L["Berthold <The Doorman>"], 10010 };
		{ GREN.." 3') "..L["Calliard <The Nightman>"], 10011 };
		{ GREN.." 4') "..L["Koren <The Blacksmith>"], 10012 };
		{ GREN.." 5') "..L["Bennett <The Sergeant at Arms>"], 10013 };
		{ GREN.." 6') "..L["Keanna's Log"], 10014 };
		{ GREN.." 7') "..L["Ebonlocke <The Noble>"], 10015 };
		{ GREN.." 8') "..L["Sebastian <The Organist>"], 10016 };
		{ GREN.." 9') "..L["Barnes <The Stage Manager>"], 10017 };
	};
	KarazhanEnd = {
		ZoneName = { BZ["Karazhan"]..ALC["MapB"]..ALC["L-Parenthesis"]..ALC["End"]..ALC["R-Parenthesis"] };
		Location = { BZ["Deadwind Pass"] };
		DungeonID = "175";
		Acronym = L["Kara"];
		PlayerLimit = "10";
		WorldMapID = "799";
		JournalInstanceID = "745";
		Module = "Atlas_BurningCrusade";
		PrevMap = "KarazhanStart";
		{ ORNG..REPUTATION..ALC["Colon"]..BF["The Violet Eye"] };
		{ BLUE.." I) "..L["Path to the Broken Stairs"], 10001 };
		{ BLUE.." J) "..L["Broken Stairs"], 10002 };
		{ BLUE.." K) "..L["Ramp to Guardian's Library"]..ALC["L-Parenthesis"]..Atlas_GetBossName("Shade of Aran")..ALC["R-Parenthesis"], 10003 };
		{ BLUE.." L) "..L["Mysterious Bookshelf"]..ALC["L-Parenthesis"]..Atlas_GetBossName("Terestian Illhoof")..ALC["R-Parenthesis"], 10004 };
		{ BLUE.." M) "..L["Ramp up to the Celestial Watch"]..ALC["L-Parenthesis"]..Atlas_GetBossName("Netherspite")..ALC["R-Parenthesis"], 10005 };
		{ BLUE..INDENT..L["Ramp down to the Gamesman's Hall"]..ALC["L-Parenthesis"]..Atlas_GetBossName("Chess Event", 1764)..ALC["R-Parenthesis"], 1764 };
		{ BLUE.." N) "..L["Ramp to Medivh's Chamber"], 10006 };
		{ BLUE.." O) "..L["Spiral Stairs to Netherspace"]..ALC["L-Parenthesis"]..Atlas_GetBossName("Prince Malchezaar")..ALC["R-Parenthesis"], 10007 };
		{ WHIT.." 7) "..Atlas_GetBossName("The Curator"), 10008 };
		{ WHIT.." 8) "..Atlas_GetBossName("Terestian Illhoof", 1560), 1560 };
		{ WHIT..INDENT..Atlas_GetBossName("Kil'rek")..ALC["L-Parenthesis"]..ALC["Imp"]..ALC["R-Parenthesis"] };
		{ WHIT.." 9) "..Atlas_GetBossName("Shade of Aran", 1559), 1559 };
		{ WHIT.."10) "..Atlas_GetBossName("Netherspite", 1561), 1561 };
		{ WHIT.."11) "..Atlas_GetBossName("Chess Event", 1562), 1562 };
		{ GREN..INDENT..Atlas_GetBossName("Dust Covered Chest") };
		{ WHIT.."12) "..Atlas_GetBossName("Prince Malchezaar", 1563), 1563 };
		{ GREN.."10') "..L["Wravien <The Mage>"], 10014 };
		{ GREN.."11') "..L["Gradav <The Warlock>"], 10015 };
		{ GREN.."12') "..L["Kamsis <The Conjurer>"], 10016 };
		{ GREN.."13') "..L["Ythyar"]..ALC["L-Parenthesis"]..ALC["Repair"]..ALC["Comma"]..ALC["Rewards"]..ALC["R-Parenthesis"], 10017 };
		{ GREN.."14') "..L["Echo of Medivh"], 10018 };
	};
	MagistersTerrace = {
		ZoneName = { BZ["Magisters' Terrace"] };
		Location = { BZ["Isle of Quel'Danas"] };
		DungeonID = "198";
		DungeonHeroicID = "201";
		Acronym = L["MaT"];
		WorldMapID = "798";
		JournalInstanceID = "249";
		Module = "Atlas_BurningCrusade";
		{ ORNG..REPUTATION..ALC["Colon"]..BF["Shattered Sun Offensive"] };
		{ BLUE.." A) "..ALC["Entrance"], 10001 };
		{ GREN..INDENT..L["Exarch Larethor"] };
		{ BLUE.." B) "..ALC["Exit"]..ALC["L-Parenthesis"]..ALC["Portal"]..ALC["R-Parenthesis"], 10002 };
		{ WHIT.." 1) "..Atlas_GetBossName("Selin Fireheart", 530), 530 };
		{ GREN..INDENT..L["Fel Crystals"] };
		{ WHIT.." 2) "..Atlas_GetBossName("Vexallus", 531), 531 };
		{ WHIT.." 3) "..Atlas_GetBossName("Priestess Delrissa", 532)..ALC["L-Parenthesis"]..ALC["Lower"]..ALC["R-Parenthesis"], 532 };
		{ WHIT..INDENT..L["Apoko"]..ALC["L-Parenthesis"]..ALC["Lower"]..ALC["Comma"]..ALC["Random"]..ALC["Comma"]..Atlas_GetClassName("SHAMAN")..ALC["R-Parenthesis"] };
		{ WHIT..INDENT..L["Eramas Brightblaze"]..ALC["L-Parenthesis"]..ALC["Lower"]..ALC["Comma"]..ALC["Random"]..ALC["Comma"]..Atlas_GetClassName("MONK")..ALC["R-Parenthesis"] };
		{ WHIT..INDENT..L["Ellrys Duskhallow"]..ALC["L-Parenthesis"]..ALC["Lower"]..ALC["Comma"]..ALC["Random"]..ALC["Comma"]..Atlas_GetClassName("WARLOCK")..ALC["R-Parenthesis"] };
		{ WHIT..INDENT..INDENT..L["Fizzle"]..ALC["L-Parenthesis"]..ALC["Lower"]..ALC["Comma"]..ALC["Random"]..ALC["R-Parenthesis"] };
		{ WHIT..INDENT..L["Garaxxas"]..ALC["L-Parenthesis"]..ALC["Lower"]..ALC["Comma"]..ALC["Random"]..ALC["Comma"]..Atlas_GetClassName("HUNTER")..ALC["R-Parenthesis"] };
		{ WHIT..INDENT..INDENT..L["Sliver <Garaxxas' Pet>"]..ALC["L-Parenthesis"]..ALC["Lower"]..ALC["Comma"]..ALC["Random"]..ALC["R-Parenthesis"] };
		{ WHIT..INDENT..L["Kagani Nightstrike"]..ALC["L-Parenthesis"]..ALC["Lower"]..ALC["Comma"]..ALC["Random"]..ALC["Comma"]..Atlas_GetClassName("ROGUE")..ALC["R-Parenthesis"] };
		{ WHIT..INDENT..L["Warlord Salaris"]..ALC["L-Parenthesis"]..ALC["Lower"]..ALC["Comma"]..ALC["Random"]..ALC["Comma"]..Atlas_GetClassName("WARRIOR")..ALC["R-Parenthesis"] };
		{ WHIT..INDENT..L["Yazzai"]..ALC["L-Parenthesis"]..ALC["Lower"]..ALC["Comma"]..ALC["Random"]..ALC["Comma"]..Atlas_GetClassName("MAGE")..ALC["R-Parenthesis"] };
		{ WHIT..INDENT..L["Zelfan"]..ALC["L-Parenthesis"]..ALC["Lower"]..ALC["Comma"]..ALC["Random"]..ALC["Comma"]..ALC["Engineer"]..ALC["R-Parenthesis"] };
		{ WHIT.." 4) "..Atlas_GetBossName("Kael'thas Sunstrider", 533), 533 };
		{ GREN.." 1') "..L["Tyrith"], 10003 };
		{ GREN.." 2') "..L["Scrying Orb"], 10004 };
		{ GREN..INDENT..Atlas_GetBossName("Kalecgos") };
	};
	SunwellPlateau = {
		ZoneName = { BZ["Sunwell Plateau"] };
		Location = { BZ["Isle of Quel'Danas"] };
		DungeonID = "199";
		Acronym = L["SuP"];
		PlayerLimit = "25";
		WorldMapID = "789";
		JournalInstanceID = "752";
		Module = "Atlas_BurningCrusade";
		{ BLUE.." A) "..ALC["Entrance"], 10001 };
		{ WHIT.." 1) "..Atlas_GetBossName("Kalecgos", 1591), 1591 };
		{ WHIT..INDENT..Atlas_GetBossName("Sathrovarr the Corruptor") };
		{ WHIT.." 2) "..Atlas_GetBossName("Brutallus", 1592), 1592 };
		{ WHIT..INDENT..Atlas_GetBossName("Felmyst", 1593), 1593 };
		{ GREN..INDENT..L["Madrigosa"] };
		{ WHIT.." 3) "..Atlas_GetBossName("The Eredar Twins", 1594)..ALC["L-Parenthesis"]..ALC["Lower"]..ALC["R-Parenthesis"], 1594 };
		{ WHIT..INDENT..Atlas_GetBossName("Grand Warlock Alythess")..ALC["L-Parenthesis"]..ALC["Lower"]..ALC["R-Parenthesis"] };
		{ WHIT..INDENT..Atlas_GetBossName("Lady Sacrolash")..ALC["L-Parenthesis"]..ALC["Lower"]..ALC["R-Parenthesis"] };
		{ WHIT..INDENT..Atlas_GetBossName("M'uru", 1595)..ALC["L-Parenthesis"]..ALC["Upper"]..ALC["R-Parenthesis"], 1595 };
		{ WHIT..INDENT..Atlas_GetBossName("Entropius")..ALC["L-Parenthesis"]..ALC["Upper"]..ALC["R-Parenthesis"] };
		{ WHIT.." 4) "..Atlas_GetBossName("Kil'jaeden", 1596), 1596 };
	};
	TempestKeepEnt = {
		ZoneName = { BZ["Tempest Keep"]..ALC["L-Parenthesis"]..ALC["Entrance"]..ALC["R-Parenthesis"] };
		Location = { BZ["Netherstorm"] };
		LevelRange = "70-73";
		MinLevel= "67";
		PlayerLimit = "5/25";
		Acronym = L["TK"];
		Module = "Atlas_BurningCrusade";
		{ BLUE.." A) "..BZ["The Mechanar"], 10001 };
		{ BLUE.." B) "..BZ["The Botanica"], 10002 };
		{ BLUE.." C) "..BZ["The Arcatraz"], 10003 };
		{ BLUE.." D) "..BZ["Tempest Keep"], 10004 };
	};
	TempestKeepArcatraz = {
		ZoneName = { BZ["Tempest Keep"]..ALC["Colon"]..BZ["The Arcatraz"] };
		Location = { BZ["Netherstorm"] };
		DungeonID = "174";
		DungeonHeroicID = "190";
		Acronym = L["Arca"];
		WorldMapID = "731";
		JournalInstanceID = "254";
		Module = "Atlas_BurningCrusade";
		{ ORNG..REPUTATION..ALC["Colon"]..BF["The Sha'tar"] };
		{ BLUE.." A) "..ALC["Entrance"], 10001 };
		{ WHIT.." 1) "..Atlas_GetBossName("Zereketh the Unbound", 548), 548 };
		{ WHIT.." 2) "..Atlas_GetBossName("Dalliah the Doomsayer", 549), 549 };
		{ WHIT.." 3) "..Atlas_GetBossName("Wrath-Scryer Soccothrates", 550), 550 };
		{ WHIT.." 4) "..Atlas_GetBossName("Harbinger Skyriss", 551), 551 };
		{ WHIT..INDENT..Atlas_GetBossName("Warden Mellichar") };
		{ GREN..INDENT..L["Millhouse Manastorm"] };
		{ ORNG.." 1) "..L["Third Fragment Guardian"], 10002 };
		{ GREN..INDENT..ALC["Arcane Container"] };
		{ GREN.." 1') "..L["Udalo"], 10003 };
	};
	TempestKeepBotanica = {
		ZoneName = { BZ["Tempest Keep"]..ALC["Colon"]..BZ["The Botanica"] };
		Location = { BZ["Netherstorm"] };
		DungeonID = "173";
		DungeonHeroicID = "191";
		Acronym = L["Bota"];
		WorldMapID = "729";
		JournalInstanceID = "257";
		Module = "Atlas_BurningCrusade";
		{ ORNG..REPUTATION..ALC["Colon"]..BF["The Sha'tar"] };
		{ BLUE.." A) "..ALC["Entrance"], 10001 };
		{ BLUE.." B) "..ALC["Exit"], 10002 };
		{ WHIT.." 1) "..Atlas_GetBossName("Commander Sarannis", 558), 558 };
		{ WHIT.." 2) "..Atlas_GetBossName("High Botanist Freywinn", 559), 559 };
		{ WHIT.." 3) "..Atlas_GetBossName("Thorngrin the Tender", 560), 560 };
		{ WHIT.." 4) "..Atlas_GetBossName("Laj", 561), 561 };
		{ WHIT.." 5) "..Atlas_GetBossName("Warp Splinter", 562), 562 };
	};
	TempestKeepMechanar = {
		ZoneName = { BZ["Tempest Keep"]..ALC["Colon"]..BZ["The Mechanar"] };
		Location = { BZ["Netherstorm"] };
		DungeonID = "172";
		DungeonHeroicID = "192";
		Acronym = L["Mech"];
		WorldMapID = "730";
		JournalInstanceID = "258";
		Module = "Atlas_BurningCrusade";
		{ ORNG..REPUTATION..ALC["Colon"]..BF["The Sha'tar"] };
		{ BLUE.." A) "..ALC["Entrance"], 10001 };
		{ BLUE.." B) "..ALC["Exit"], 10002 };
		{ WHIT.." 1) "..Atlas_GetBossName("Gatewatcher Gyro-Kill"), 10003 };
		{ WHIT.." 2) "..Atlas_GetBossName("Gatewatcher Iron-Hand"), 10004 };
		{ WHIT.." 3) "..Atlas_GetBossName("Mechano-Lord Capacitus", 563)..ALC["L-Parenthesis"]..ALC["Wanders"]..ALC["R-Parenthesis"], 563 };
		{ GREN..INDENT..L["Overcharged Manacell"] };
		{ WHIT.." 4) "..Atlas_GetBossName("Nethermancer Sepethrea", 564), 564 };
		{ WHIT.." 5) "..Atlas_GetBossName("Pathaleon the Calculator", 565), 565 };
		{ GREN.." 1') "..Atlas_GetBossName("Cache of the Legion"), 10005 };
	};
	TempestKeepTheEye = {
		ZoneName = { BZ["Tempest Keep"]..ALC["Colon"]..BZ["Tempest Keep"] };
		Location = { BZ["Netherstorm"] };
		DungeonID = "193";
		Acronym = L["TK"];
		PlayerLimit = "25";
		WorldMapID = "729";
		JournalInstanceID = "749";
		Module = "Atlas_BurningCrusade";
		{ ORNG..REPUTATION..ALC["Colon"]..BF["The Sha'tar"] };
		{ BLUE.." A) "..ALC["Entrance"], 10001 };
		{ WHIT.." 1) "..Atlas_GetBossName("Al'ar", 1573), 1573 };
		{ WHIT.." 2) "..Atlas_GetBossName("Void Reaver", 1574), 1574 };
		{ WHIT.." 3) "..Atlas_GetBossName("High Astromancer Solarian", 1575), 1575 };
		{ WHIT.." 4) "..Atlas_GetBossName("Kael'thas Sunstrider", 1576), 1576 };
		{ WHIT..INDENT..Atlas_GetBossName("Thaladred the Darkener")..ALC["L-Parenthesis"]..Atlas_GetClassName("WARRIOR")..ALC["R-Parenthesis"] };
		{ WHIT..INDENT..Atlas_GetBossName("Master Engineer Telonicus")..ALC["L-Parenthesis"]..Atlas_GetClassName("HUNTER")..ALC["R-Parenthesis"] };
		{ WHIT..INDENT..Atlas_GetBossName("Grand Astromancer Capernian")..ALC["L-Parenthesis"]..Atlas_GetClassName("MAGE")..ALC["R-Parenthesis"] };
		{ WHIT..INDENT..Atlas_GetBossName("Lord Sanguinar")..ALC["L-Parenthesis"]..Atlas_GetClassName("PALADIN")..ALC["R-Parenthesis"] };
	};
};

for k, v in pairs(myMaps) do
	AtlasMaps[k] = v;
end
